=======
History
=======

0.2.0 (2021-08-14)
------------------

* First Release on PyPI.
* Made path to kube config variable.
* Port-forwarding became non-blocking.
* Fixed verification bug when port was None.
* Added throwing own error.


0.1.0 (2021-08-09)
------------------

* First release on Test PyPI.
* Blocking port-forward with fixed path for kube config.
